@@ -1,12 +1,12 @@
 package Encode::JP::Mobile;
-our $VERSION = "0.22";
+our $VERSION = "0.23";
 
 use Encode;
 use XSLoader;
 XSLoader::load(__PACKAGE__, $VERSION);
 
 use base qw( Exporter );
-@EXPORT_OK = qw( InDoCoMoPictograms InKDDIPictograms InSoftBankPictograms InAirEdgePictograms InMobileJPPictograms InKDDISoftBankConflicts);
+@EXPORT_OK = qw( InDoCoMoPictograms InKDDIPictograms InSoftBankPictograms InAirEdgePictograms InMobileJPPictograms InKDDISoftBankConflicts InKDDICP932Pictograms InKDDIAutoPictograms);
 %EXPORT_TAGS = ( props => [@EXPORT_OK] );
 
 use Encode::Alias;
@@ -46,10 +46,15 @@ E6CE\tE757
 END
 }
 
-sub InKDDIPictograms {
+sub InKDDICP932Pictograms {
     return <<END;
 E468\tE5DF
 EA80\tEB88
+END
+}
+
+sub InKDDIAutoPictograms {
+    return <<END;
 EC40\tEC7E
 EC80\tECFC
 ED40\tED8D
@@ -60,6 +65,10 @@ F080\tF0FC
 END
 }
 
+sub InKDDIPictograms {
+    return join "\n", InKDDICP932Pictograms(), InKDDIAutoPictograms();
+}
+
 sub InSoftBankPictograms {
     return <<END;
 E001\tE05A
@@ -99,6 +108,7 @@ E501\tE537
 END
 }
 
+
 1;
 
 =encoding utf-8
@@ -259,6 +269,10 @@ I<x-utf8-airh>, I<x-utf8-airedge> は存在しません。Willcom 端末は utf8
 
 =item InKDDISoftBankConflicts
 
+=item InKDDICP932Pictograms
+
+=item InKDDIAutoPictograms
+
 =back
 
 InKDDIPictograms はCP932ベースと裏KDDI Unicodeの双方を含みます。
@@ -278,6 +292,8 @@ InKDDISoftBankConflicts は SoftBank と KDDI (x-sjis-kddi を利用した場合
       }
   }
 
+I<InKDDICP932Pictograms>, I<InKDDIAutoPictograms> はそれぞれ、I<x-sjis-kddi>, I<x-sjis-kddi-auto> のマッピングによって得られる Unicode 私用領域のレンジをあらわし、InKDDIPictograms はその2つをマージしたものとして扱われます。
+
 =head1 BACKWARD COMPATIBLITY
 
 バージョン 0.07 から、モジュールで利用するエンコーディング名を I<x-sjis-*> のように変更しました。以前の I<shift_jis-*> というエイリアスも残してありますが、将来のリリースで削除される予定です。
